# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogment/api/datalog.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogment.api import common_pb2 as cogment_dot_api_dot_common__pb2
from cogment.api import environment_pb2 as cogment_dot_api_dot_environment__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x63ogment/api/datalog.proto\x12\ncogmentAPI\x1a\x18\x63ogment/api/common.proto\x1a\x1d\x63ogment/api/environment.proto\x1a\x19google/protobuf/any.proto\"{\n\x14RunTrialDatalogInput\x12/\n\x0ctrial_params\x18\x01 \x01(\x0b\x32\x17.cogmentAPI.TrialParamsH\x00\x12+\n\x06sample\x18\x02 \x01(\x0b\x32\x19.cogmentAPI.DatalogSampleH\x00\x42\x05\n\x03msg\"\x17\n\x15RunTrialDatalogOutput\"\x84\x01\n\nSampleInfo\x12\x13\n\x0bout_of_sync\x18\x05 \x01(\x08\x12\x0f\n\x07tick_id\x18\x01 \x01(\x04\x12\x11\n\ttimestamp\x18\x02 \x01(\x06\x12%\n\x05state\x18\x03 \x01(\x0e\x32\x16.cogmentAPI.TrialState\x12\x16\n\x0especial_events\x18\x04 \x03(\t\"\x8c\x02\n\rDatalogSample\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.cogmentAPI.SampleInfo\x12\x30\n\x0cobservations\x18\x02 \x01(\x0b\x32\x1a.cogmentAPI.ObservationSet\x12#\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32\x12.cogmentAPI.Action\x12#\n\x07rewards\x18\x04 \x03(\x0b\x32\x12.cogmentAPI.Reward\x12%\n\x08messages\x18\x05 \x03(\x0b\x32\x13.cogmentAPI.Message\x12\x16\n\x0e\x64\x65\x66\x61ult_actors\x18\x06 \x03(\r\x12\x1a\n\x12unavailable_actors\x18\x07 \x03(\r\"!\n\x0eTrialConfig_v1\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"!\n\x0e\x41\x63torConfig_v1\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"\'\n\x14\x45nvironmentConfig_v1\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"r\n\x14\x45nvironmentParams_v1\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x30\n\x06\x63onfig\x18\x02 \x01(\x0b\x32 .cogmentAPI.EnvironmentConfig_v1\x12\x16\n\x0eimplementation\x18\x03 \x01(\t\"\x89\x01\n\x0e\x41\x63torParams_v1\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x61\x63tor_class\x18\x02 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x03 \x01(\t\x12\x16\n\x0eimplementation\x18\x04 \x01(\t\x12*\n\x06\x63onfig\x18\x05 \x01(\x0b\x32\x1a.cogmentAPI.ActorConfig_v1\"\xd0\x01\n\x0eTrialParams_v1\x12\x30\n\x0ctrial_config\x18\x01 \x01(\x0b\x32\x1a.cogmentAPI.TrialConfig_v1\x12\x35\n\x0b\x65nvironment\x18\x02 \x01(\x0b\x32 .cogmentAPI.EnvironmentParams_v1\x12*\n\x06\x61\x63tors\x18\x03 \x03(\x0b\x32\x1a.cogmentAPI.ActorParams_v1\x12\x11\n\tmax_steps\x18\x04 \x01(\r\x12\x16\n\x0emax_inactivity\x18\x05 \x01(\r\"7\n\x12ObservationData_v1\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x12\x10\n\x08snapshot\x18\x02 \x01(\x08\"\x81\x01\n\x11ObservationSet_v1\x12\x0f\n\x07tick_id\x18\x01 \x01(\x12\x12\x11\n\ttimestamp\x18\x02 \x01(\x06\x12\x34\n\x0cobservations\x18\x03 \x03(\x0b\x32\x1e.cogmentAPI.ObservationData_v1\x12\x12\n\nactors_map\x18\x04 \x03(\x05\"-\n\tAction_v1\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x12\x0f\n\x07tick_id\x18\x02 \x01(\x12\"r\n\x0fRewardSource_v1\x12\x13\n\x0bsender_name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02\x12\x12\n\nconfidence\x18\x03 \x01(\x02\x12\'\n\tuser_data\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\"p\n\tReward_v1\x12\x15\n\rreceiver_name\x18\x01 \x01(\t\x12\x0f\n\x07tick_id\x18\x02 \x01(\x12\x12\r\n\x05value\x18\x03 \x01(\x02\x12,\n\x07sources\x18\x04 \x03(\x0b\x32\x1b.cogmentAPI.RewardSource_v1\"p\n\nMessage_v1\x12\x0f\n\x07tick_id\x18\x01 \x01(\x12\x12\x13\n\x0bsender_name\x18\x02 \x01(\t\x12\x15\n\rreceiver_name\x18\x03 \x01(\t\x12%\n\x07payload\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\"\x80\x02\n\x10\x44\x61talogSample_v1\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x33\n\x0cobservations\x18\x02 \x01(\x0b\x32\x1d.cogmentAPI.ObservationSet_v1\x12&\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32\x15.cogmentAPI.Action_v1\x12&\n\x07rewards\x18\x04 \x03(\x0b\x32\x15.cogmentAPI.Reward_v1\x12(\n\x08messages\x18\x05 \x03(\x0b\x32\x16.cogmentAPI.Message_v1\x12,\n\ntrial_data\x18\x06 \x01(\x0b\x32\x18.cogmentAPI.TrialData_v1\"Y\n\x0cTrialData_v1\x12\x0f\n\x07tick_id\x18\x01 \x01(\x04\x12\x11\n\ttimestamp\x18\x02 \x01(\x06\x12%\n\x05state\x18\x03 \x01(\x0e\x32\x16.cogmentAPI.TrialState2\xab\x01\n\tDatalogSP\x12\\\n\x0fRunTrialDatalog\x12 .cogmentAPI.RunTrialDatalogInput\x1a!.cogmentAPI.RunTrialDatalogOutput\"\x00(\x01\x30\x01\x12@\n\x07Version\x12\x1a.cogmentAPI.VersionRequest\x1a\x17.cogmentAPI.VersionInfo\"\x00\x62\x06proto3')



_RUNTRIALDATALOGINPUT = DESCRIPTOR.message_types_by_name['RunTrialDatalogInput']
_RUNTRIALDATALOGOUTPUT = DESCRIPTOR.message_types_by_name['RunTrialDatalogOutput']
_SAMPLEINFO = DESCRIPTOR.message_types_by_name['SampleInfo']
_DATALOGSAMPLE = DESCRIPTOR.message_types_by_name['DatalogSample']
_TRIALCONFIG_V1 = DESCRIPTOR.message_types_by_name['TrialConfig_v1']
_ACTORCONFIG_V1 = DESCRIPTOR.message_types_by_name['ActorConfig_v1']
_ENVIRONMENTCONFIG_V1 = DESCRIPTOR.message_types_by_name['EnvironmentConfig_v1']
_ENVIRONMENTPARAMS_V1 = DESCRIPTOR.message_types_by_name['EnvironmentParams_v1']
_ACTORPARAMS_V1 = DESCRIPTOR.message_types_by_name['ActorParams_v1']
_TRIALPARAMS_V1 = DESCRIPTOR.message_types_by_name['TrialParams_v1']
_OBSERVATIONDATA_V1 = DESCRIPTOR.message_types_by_name['ObservationData_v1']
_OBSERVATIONSET_V1 = DESCRIPTOR.message_types_by_name['ObservationSet_v1']
_ACTION_V1 = DESCRIPTOR.message_types_by_name['Action_v1']
_REWARDSOURCE_V1 = DESCRIPTOR.message_types_by_name['RewardSource_v1']
_REWARD_V1 = DESCRIPTOR.message_types_by_name['Reward_v1']
_MESSAGE_V1 = DESCRIPTOR.message_types_by_name['Message_v1']
_DATALOGSAMPLE_V1 = DESCRIPTOR.message_types_by_name['DatalogSample_v1']
_TRIALDATA_V1 = DESCRIPTOR.message_types_by_name['TrialData_v1']
RunTrialDatalogInput = _reflection.GeneratedProtocolMessageType('RunTrialDatalogInput', (_message.Message,), {
  'DESCRIPTOR' : _RUNTRIALDATALOGINPUT,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.RunTrialDatalogInput)
  })
_sym_db.RegisterMessage(RunTrialDatalogInput)

RunTrialDatalogOutput = _reflection.GeneratedProtocolMessageType('RunTrialDatalogOutput', (_message.Message,), {
  'DESCRIPTOR' : _RUNTRIALDATALOGOUTPUT,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.RunTrialDatalogOutput)
  })
_sym_db.RegisterMessage(RunTrialDatalogOutput)

SampleInfo = _reflection.GeneratedProtocolMessageType('SampleInfo', (_message.Message,), {
  'DESCRIPTOR' : _SAMPLEINFO,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.SampleInfo)
  })
_sym_db.RegisterMessage(SampleInfo)

DatalogSample = _reflection.GeneratedProtocolMessageType('DatalogSample', (_message.Message,), {
  'DESCRIPTOR' : _DATALOGSAMPLE,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.DatalogSample)
  })
_sym_db.RegisterMessage(DatalogSample)

TrialConfig_v1 = _reflection.GeneratedProtocolMessageType('TrialConfig_v1', (_message.Message,), {
  'DESCRIPTOR' : _TRIALCONFIG_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialConfig_v1)
  })
_sym_db.RegisterMessage(TrialConfig_v1)

ActorConfig_v1 = _reflection.GeneratedProtocolMessageType('ActorConfig_v1', (_message.Message,), {
  'DESCRIPTOR' : _ACTORCONFIG_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.ActorConfig_v1)
  })
_sym_db.RegisterMessage(ActorConfig_v1)

EnvironmentConfig_v1 = _reflection.GeneratedProtocolMessageType('EnvironmentConfig_v1', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTCONFIG_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.EnvironmentConfig_v1)
  })
_sym_db.RegisterMessage(EnvironmentConfig_v1)

EnvironmentParams_v1 = _reflection.GeneratedProtocolMessageType('EnvironmentParams_v1', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTPARAMS_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.EnvironmentParams_v1)
  })
_sym_db.RegisterMessage(EnvironmentParams_v1)

ActorParams_v1 = _reflection.GeneratedProtocolMessageType('ActorParams_v1', (_message.Message,), {
  'DESCRIPTOR' : _ACTORPARAMS_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.ActorParams_v1)
  })
_sym_db.RegisterMessage(ActorParams_v1)

TrialParams_v1 = _reflection.GeneratedProtocolMessageType('TrialParams_v1', (_message.Message,), {
  'DESCRIPTOR' : _TRIALPARAMS_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialParams_v1)
  })
_sym_db.RegisterMessage(TrialParams_v1)

ObservationData_v1 = _reflection.GeneratedProtocolMessageType('ObservationData_v1', (_message.Message,), {
  'DESCRIPTOR' : _OBSERVATIONDATA_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.ObservationData_v1)
  })
_sym_db.RegisterMessage(ObservationData_v1)

ObservationSet_v1 = _reflection.GeneratedProtocolMessageType('ObservationSet_v1', (_message.Message,), {
  'DESCRIPTOR' : _OBSERVATIONSET_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.ObservationSet_v1)
  })
_sym_db.RegisterMessage(ObservationSet_v1)

Action_v1 = _reflection.GeneratedProtocolMessageType('Action_v1', (_message.Message,), {
  'DESCRIPTOR' : _ACTION_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.Action_v1)
  })
_sym_db.RegisterMessage(Action_v1)

RewardSource_v1 = _reflection.GeneratedProtocolMessageType('RewardSource_v1', (_message.Message,), {
  'DESCRIPTOR' : _REWARDSOURCE_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.RewardSource_v1)
  })
_sym_db.RegisterMessage(RewardSource_v1)

Reward_v1 = _reflection.GeneratedProtocolMessageType('Reward_v1', (_message.Message,), {
  'DESCRIPTOR' : _REWARD_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.Reward_v1)
  })
_sym_db.RegisterMessage(Reward_v1)

Message_v1 = _reflection.GeneratedProtocolMessageType('Message_v1', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.Message_v1)
  })
_sym_db.RegisterMessage(Message_v1)

DatalogSample_v1 = _reflection.GeneratedProtocolMessageType('DatalogSample_v1', (_message.Message,), {
  'DESCRIPTOR' : _DATALOGSAMPLE_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.DatalogSample_v1)
  })
_sym_db.RegisterMessage(DatalogSample_v1)

TrialData_v1 = _reflection.GeneratedProtocolMessageType('TrialData_v1', (_message.Message,), {
  'DESCRIPTOR' : _TRIALDATA_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialData_v1)
  })
_sym_db.RegisterMessage(TrialData_v1)

_DATALOGSP = DESCRIPTOR.services_by_name['DatalogSP']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RUNTRIALDATALOGINPUT._serialized_start=125
  _RUNTRIALDATALOGINPUT._serialized_end=248
  _RUNTRIALDATALOGOUTPUT._serialized_start=250
  _RUNTRIALDATALOGOUTPUT._serialized_end=273
  _SAMPLEINFO._serialized_start=276
  _SAMPLEINFO._serialized_end=408
  _DATALOGSAMPLE._serialized_start=411
  _DATALOGSAMPLE._serialized_end=679
  _TRIALCONFIG_V1._serialized_start=681
  _TRIALCONFIG_V1._serialized_end=714
  _ACTORCONFIG_V1._serialized_start=716
  _ACTORCONFIG_V1._serialized_end=749
  _ENVIRONMENTCONFIG_V1._serialized_start=751
  _ENVIRONMENTCONFIG_V1._serialized_end=790
  _ENVIRONMENTPARAMS_V1._serialized_start=792
  _ENVIRONMENTPARAMS_V1._serialized_end=906
  _ACTORPARAMS_V1._serialized_start=909
  _ACTORPARAMS_V1._serialized_end=1046
  _TRIALPARAMS_V1._serialized_start=1049
  _TRIALPARAMS_V1._serialized_end=1257
  _OBSERVATIONDATA_V1._serialized_start=1259
  _OBSERVATIONDATA_V1._serialized_end=1314
  _OBSERVATIONSET_V1._serialized_start=1317
  _OBSERVATIONSET_V1._serialized_end=1446
  _ACTION_V1._serialized_start=1448
  _ACTION_V1._serialized_end=1493
  _REWARDSOURCE_V1._serialized_start=1495
  _REWARDSOURCE_V1._serialized_end=1609
  _REWARD_V1._serialized_start=1611
  _REWARD_V1._serialized_end=1723
  _MESSAGE_V1._serialized_start=1725
  _MESSAGE_V1._serialized_end=1837
  _DATALOGSAMPLE_V1._serialized_start=1840
  _DATALOGSAMPLE_V1._serialized_end=2096
  _TRIALDATA_V1._serialized_start=2098
  _TRIALDATA_V1._serialized_end=2187
  _DATALOGSP._serialized_start=2190
  _DATALOGSP._serialized_end=2361
# @@protoc_insertion_point(module_scope)
